ifgen.common package — docs

Skip to main content
`Ctrl`+`K`

# ifgen.common package

## Module contents

A module for generating shared headers and sources.

ifgen.common.common_endianness(writer: IndentedFileWriter, task: GenerateTask) → None

  Write endianness-related content.

ifgen.common.create_common(task: GenerateTask) → None

  Create a unit test for the enum string-conversion methods.

ifgen.common.create_common_test(task: GenerateTask) → None

  Create a unit test for the enum string-conversion methods.

ifgen.common.endianness_enum(writer: IndentedFileWriter) → None

  Add methods for enum types that require swapping.

ifgen.common.endianness_float(writer: IndentedFileWriter) → None

  Add methods for floating-point types that require swapping.

ifgen.common.endianness_integral(writer: IndentedFileWriter) → None

  Add methods for integral types that require swapping.

ifgen.common.endianness_native(writer: IndentedFileWriter) → None

  Add methods for native endianness (no swap).

ifgen.common.endianness_single(writer: IndentedFileWriter) → None

  Add methods for byte-sized primitives.